@@ -64,7 +64,7 @@ def query(constraints, credential_and_key=None):
       of values to unknowns that satisfies the constraints.
     '''
     
-    parms = {'command': 'vdl_query'}
+    parms = {'command': 'query'}
     scanned_constraints = []
     files = dict()
     for input_constraint in constraints:
@@ -90,7 +90,7 @@ def update(changes, credential_and_key=None):
     Make a set of virtual data lake changes.
         
     Parameters:
-      * commands: a `Change` object or a list of `Change` objects
+      * changes: a `Change` object or a list of `Change` objects
       * credential_and_key: a 2-tuple whose first element is an `Itm`
         object that is a credential to authorize the request, and
         whose second element is the credential's key.
@@ -110,7 +110,7 @@ def update(changes, credential_and_key=None):
     '''
     
     if isinstance(changes, Change): changes = [changes]
-    parms = {'command': 'vdl_update'}
+    parms = {'command': 'update'}
     scanned_changes = []
     files = dict()
     for change in changes:
